clojurewerkz.buffy.types.protocols


BuffyTypecljprotocol

readclj

(read bt buffer idx)

Relative read

Relative read

rewind-readclj

(rewind-read bt buffer)

Reads value at current reader position, rewinds reader index to the end of current read value.

Reads value at current reader position, rewinds reader index to the end of current read value.

rewind-writeclj

(rewind-write bt buffer value)

Writes at current writer position, rewinds writer index to the last written position.

Writes at current writer position, rewinds writer index to the last written position.

sizeclj

(size bt)

Return size of the data type

Return size of the data type

writeclj

(write bt buffer idx value)

Relative write

Relative write
source

cljdoc builds & hosts documentation for Clojure/Script libraries