(read bt buffer idx)Relative read
Relative read
(rewind-read bt buffer)Reads value at current reader position, rewinds reader index to the end of current read value.
Reads value at current reader position, rewinds reader index to the end of current read value.
(rewind-write bt buffer value)Writes at current writer position, rewinds writer index to the last written position.
Writes at current writer position, rewinds writer index to the last written position.
(size bt)Return size of the data type
Return size of the data type
(write bt buffer idx value)Relative write
Relative write
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |